@font-face {
  font-family: 'django_listing';
  src: url('../font/django_listing.eot?30413526');
  src: url('../font/django_listing.eot?30413526#iefix') format('embedded-opentype'),
       url('../font/django_listing.woff2?30413526') format('woff2'),
       url('../font/django_listing.woff?30413526') format('woff'),
       url('../font/django_listing.ttf?30413526') format('truetype'),
       url('../font/django_listing.svg?30413526#django_listing') format('svg');
  font-weight: normal;
  font-style: normal;
}
/* Chrome hack: SVG is rendered more smooth in Windozze. 100% magic, uncomment if you need it. */
/* Note, that will break hinting! In other OS-es font will be not as sharp as it could be */
/*
@media screen and (-webkit-min-device-pixel-ratio:0) {
  @font-face {
    font-family: 'django_listing';
    src: url('../font/django_listing.svg?30413526#django_listing') format('svg');
  }
}
*/

 [class^="listing-icon-"]:before, [class*=" listing-icon-"]:before {
  font-family: "django_listing";
  font-style: normal;
  font-weight: normal;
  speak: none;

  display: inline-block;
  text-decoration: inherit;
  width: 1em;
  margin-right: .2em;
  text-align: center;
  /* opacity: .8; */

  /* For safety - reset parent styles, that can break glyph codes*/
  font-variant: normal;
  text-transform: none;

  /* fix buttons height, for twitter bootstrap */
  line-height: 1em;

  /* Animation center compensation - margins should be symmetric */
  /* remove if not needed */
  margin-left: .2em;

  /* you can be more comfortable with increased icons size */
  /* font-size: 120%; */

  /* Font smoothing. That was taken from TWBS */
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;

  /* Uncomment for 3D effect */
  /* text-shadow: 1px 1px 1px rgba(127, 127, 127, 0.3); */
}

.listing-icon-download:before { content: '\e800'; } /* '' */
.listing-icon-upload:before { content: '\e801'; } /* '' */
.listing-icon-zoom-in:before { content: '\e802'; } /* '' */
.listing-icon-zoom-out:before { content: '\e803'; } /* '' */
.listing-icon-cancel:before { content: '\e804'; } /* '' */
.listing-icon-plus:before { content: '\e805'; } /* '' */
.listing-icon-cancel-circled:before { content: '\e806'; } /* '' */
.listing-icon-cancel-circled2:before { content: '\e807'; } /* '' */
.listing-icon-plus-circled:before { content: '\e808'; } /* '' */
.listing-icon-minus:before { content: '\e809'; } /* '' */
.listing-icon-minus-circled:before { content: '\e80a'; } /* '' */
.listing-icon-trash-empty:before { content: '\e80b'; } /* '' */
.listing-icon-trash-1:before { content: '\e80c'; } /* '' */
.listing-icon-trash-3:before { content: '\e80d'; } /* '' */
.listing-icon-lock:before { content: '\e80e'; } /* '' */
.listing-icon-lock-filled:before { content: '\e80f'; } /* '' */
.listing-icon-lock-1:before { content: '\e810'; } /* '' */
.listing-icon-cancel-1:before { content: '\e811'; } /* '' */
.listing-icon-arrows-cw:before { content: '\e812'; } /* '' */
.listing-icon-cog:before { content: '\e813'; } /* '' */
.listing-icon-wrench:before { content: '\e814'; } /* '' */
.listing-icon-wrench-1:before { content: '\e815'; } /* '' */
.listing-icon-cog-1:before { content: '\e816'; } /* '' */
.listing-icon-cog-outline:before { content: '\e817'; } /* '' */
.listing-icon-wrench-2:before { content: '\e818'; } /* '' */
.listing-icon-cog-2:before { content: '\e819'; } /* '' */
.listing-icon-share-1:before { content: '\e81a'; } /* '' */
.listing-icon-export:before { content: '\e81b'; } /* '' */
.listing-icon-left-dir:before { content: '\e81c'; } /* '' */
.listing-icon-down-dir:before { content: '\e81d'; } /* '' */
.listing-icon-down-open:before { content: '\e81e'; } /* '' */
.listing-icon-up-open:before { content: '\e81f'; } /* '' */
.listing-icon-up-dir:before { content: '\e820'; } /* '' */
.listing-icon-right-dir:before { content: '\e821'; } /* '' */
.listing-icon-left-open:before { content: '\e822'; } /* '' */
.listing-icon-right-open:before { content: '\e823'; } /* '' */
.listing-icon-down-big:before { content: '\e824'; } /* '' */
.listing-icon-left-big:before { content: '\e825'; } /* '' */
.listing-icon-right-big:before { content: '\e826'; } /* '' */
.listing-icon-up-big:before { content: '\e827'; } /* '' */
.listing-icon-right-hand:before { content: '\e828'; } /* '' */
.listing-icon-left-hand:before { content: '\e829'; } /* '' */
.listing-icon-up-hand:before { content: '\e82a'; } /* '' */
.listing-icon-down-hand:before { content: '\e82b'; } /* '' */
.listing-icon-to-end:before { content: '\e82c'; } /* '' */
.listing-icon-to-end-alt:before { content: '\e82d'; } /* '' */
.listing-icon-to-start:before { content: '\e82e'; } /* '' */
.listing-icon-to-start-alt:before { content: '\e82f'; } /* '' */
.listing-icon-spin1:before { content: '\e830'; } /* '' */
.listing-icon-spin2:before { content: '\e831'; } /* '' */
.listing-icon-spin3:before { content: '\e832'; } /* '' */
.listing-icon-fast-fw:before { content: '\e833'; } /* '' */
.listing-icon-spin4:before { content: '\e834'; } /* '' */
.listing-icon-fast-bw:before { content: '\e835'; } /* '' */
.listing-icon-down-bold:before { content: '\e836'; } /* '' */
.listing-icon-left-bold:before { content: '\e837'; } /* '' */
.listing-icon-spin5:before { content: '\e838'; } /* '' */
.listing-icon-spin6:before { content: '\e839'; } /* '' */
.listing-icon-right-bold:before { content: '\e83a'; } /* '' */
.listing-icon-up-bold:before { content: '\e83b'; } /* '' */
.listing-icon-down-thin:before { content: '\e83c'; } /* '' */
.listing-icon-trash-2:before { content: '\e83d'; } /* '' */
.listing-icon-left-thin:before { content: '\e83e'; } /* '' */
.listing-icon-right-thin:before { content: '\e83f'; } /* '' */
.listing-icon-up-thin:before { content: '\e840'; } /* '' */
.listing-icon-to-end-1:before { content: '\e841'; } /* '' */
.listing-icon-to-start-1:before { content: '\e842'; } /* '' */
.listing-icon-fast-forward:before { content: '\e843'; } /* '' */
.listing-icon-fast-backward:before { content: '\e844'; } /* '' */
.listing-icon-left-open-outline:before { content: '\e845'; } /* '' */
.listing-icon-left-open-1:before { content: '\e846'; } /* '' */
.listing-icon-right-open-outline:before { content: '\e847'; } /* '' */
.listing-icon-right-open-1:before { content: '\e848'; } /* '' */
.listing-icon-down-1:before { content: '\e849'; } /* '' */
.listing-icon-left-1:before { content: '\e84a'; } /* '' */
.listing-icon-right-1:before { content: '\e84b'; } /* '' */
.listing-icon-up-1:before { content: '\e84c'; } /* '' */
.listing-icon-down-outline:before { content: '\e84d'; } /* '' */
.listing-icon-th-large:before { content: '\e84e'; } /* '' */
.listing-icon-th:before { content: '\e84f'; } /* '' */
.listing-icon-th-list:before { content: '\e850'; } /* '' */
.listing-icon-grid:before { content: '\e851'; } /* '' */
.listing-icon-th-list-1:before { content: '\e852'; } /* '' */
.listing-icon-th-1:before { content: '\e853'; } /* '' */
.listing-icon-th-large-1:before { content: '\e854'; } /* '' */
.listing-icon-th-2:before { content: '\e855'; } /* '' */
.listing-icon-th-list-3:before { content: '\e856'; } /* '' */
.listing-icon-view-mode:before { content: '\e857'; } /* '' */
.listing-icon-menu-2:before { content: '\e858'; } /* '' */
.listing-icon-th-list-4:before { content: '\e859'; } /* '' */
.listing-icon-th-3:before { content: '\e85a'; } /* '' */
.listing-icon-th-large-2:before { content: '\e85b'; } /* '' */
.listing-icon-left-outline:before { content: '\e85c'; } /* '' */
.listing-icon-right-outline:before { content: '\e85d'; } /* '' */
.listing-icon-up-outline:before { content: '\e85e'; } /* '' */
.listing-icon-down-small:before { content: '\e85f'; } /* '' */
.listing-icon-left-small:before { content: '\e860'; } /* '' */
.listing-icon-right-small:before { content: '\e861'; } /* '' */
.listing-icon-up-small:before { content: '\e862'; } /* '' */
.listing-icon-fast-fw-outline:before { content: '\e863'; } /* '' */
.listing-icon-fast-fw-1:before { content: '\e864'; } /* '' */
.listing-icon-rewind-outline:before { content: '\e865'; } /* '' */
.listing-icon-rewind:before { content: '\e866'; } /* '' */
.listing-icon-plus-1:before { content: '\e867'; } /* '' */
.listing-icon-plus-circle:before { content: '\e868'; } /* '' */
.listing-icon-minus-1:before { content: '\e869'; } /* '' */
.listing-icon-minus-circle:before { content: '\e86a'; } /* '' */
.listing-icon-down-2:before { content: '\e86b'; } /* '' */
.listing-icon-left-2:before { content: '\e86c'; } /* '' */
.listing-icon-right-2:before { content: '\e86d'; } /* '' */
.listing-icon-up-2:before { content: '\e86e'; } /* '' */
.listing-icon-down-circle:before { content: '\e86f'; } /* '' */
.listing-icon-left-circle:before { content: '\e870'; } /* '' */
.listing-icon-right-circle:before { content: '\e871'; } /* '' */
.listing-icon-up-circle:before { content: '\e872'; } /* '' */
.listing-icon-down-3:before { content: '\e873'; } /* '' */
.listing-icon-left-3:before { content: '\e874'; } /* '' */
.listing-icon-right-3:before { content: '\e875'; } /* '' */
.listing-icon-up-3:before { content: '\e876'; } /* '' */
.listing-icon-down-circled-1:before { content: '\e877'; } /* '' */
.listing-icon-left-circled-1:before { content: '\e878'; } /* '' */
.listing-icon-right-circled-1:before { content: '\e879'; } /* '' */
.listing-icon-up-circled-1:before { content: '\e87a'; } /* '' */
.listing-icon-down-circle-1:before { content: '\e87b'; } /* '' */
.listing-icon-left-circle-1:before { content: '\e87c'; } /* '' */
.listing-icon-right-circle-1:before { content: '\e87d'; } /* '' */
.listing-icon-up-circle-1:before { content: '\e87e'; } /* '' */
.listing-icon-share-3:before { content: '\e87f'; } /* '' */
.listing-icon-ellipsis:before { content: '\e880'; } /* '' */
.listing-icon-add-1:before { content: '\e881'; } /* '' */
.listing-icon-add-2:before { content: '\e882'; } /* '' */
.listing-icon-add-3:before { content: '\e883'; } /* '' */
.listing-icon-add:before { content: '\e884'; } /* '' */
.listing-icon-heart:before { content: '\e885'; } /* '' */
.listing-icon-heart-empty:before { content: '\e886'; } /* '' */
.listing-icon-star:before { content: '\e887'; } /* '' */
.listing-icon-star-empty:before { content: '\e888'; } /* '' */
.listing-icon-block:before { content: '\e88a'; } /* '' */
.listing-icon-eye:before { content: '\e88b'; } /* '' */
.listing-icon-eye-off:before { content: '\e88c'; } /* '' */
.listing-icon-attention:before { content: '\e88d'; } /* '' */
.listing-icon-info-circled:before { content: '\e88e'; } /* '' */
.listing-icon-attention-circled:before { content: '\e88f'; } /* '' */
.listing-icon-ok:before { content: '\e890'; } /* '' */
.listing-icon-ok-circled:before { content: '\e891'; } /* '' */
.listing-icon-ok-circled2:before { content: '\e892'; } /* '' */
.listing-icon-check:before { content: '\e893'; } /* '' */
.listing-icon-ok-outline:before { content: '\e894'; } /* '' */
.listing-icon-ok-1:before { content: '\e895'; } /* '' */
.listing-icon-check-1:before { content: '\e896'; } /* '' */
.listing-icon-check-outline:before { content: '\e897'; } /* '' */
.listing-icon-ok-circle:before { content: '\e898'; } /* '' */
.listing-icon-ok-2:before { content: '\e899'; } /* '' */
.listing-icon-check-2:before { content: '\e89a'; } /* '' */
.listing-icon-pencil:before { content: '\e89b'; } /* '' */
.listing-icon-lock-2:before { content: '\e89c'; } /* '' */
.listing-icon-lock-open:before { content: '\e89d'; } /* '' */
.listing-icon-magnifier:before { content: '\e89f'; } /* '' */
.listing-icon-file-pdf-1:before { content: '\e8a0'; } /* '' */
.listing-icon-file-word-1:before { content: '\e8a1'; } /* '' */
.listing-icon-file-excel-1:before { content: '\e8a2'; } /* '' */
.listing-icon-file-code-1:before { content: '\e8a3'; } /* '' */
.listing-icon-sliders-1:before { content: '\e8a4'; } /* '' */
.listing-icon-menu-1:before { content: '\f008'; } /* '' */
.listing-icon-th-list-2:before { content: '\f009'; } /* '' */
.listing-icon-th-thumb:before { content: '\f00a'; } /* '' */
.listing-icon-check-empty:before { content: '\f096'; } /* '' */
.listing-icon-github-circled:before { content: '\f09b'; } /* '' */
.listing-icon-left-circled:before { content: '\f0a8'; } /* '' */
.listing-icon-right-circled:before { content: '\f0a9'; } /* '' */
.listing-icon-up-circled:before { content: '\f0aa'; } /* '' */
.listing-icon-down-circled:before { content: '\f0ab'; } /* '' */
.listing-icon-menu:before { content: '\f0c9'; } /* '' */
.listing-icon-table:before { content: '\f0ce'; } /* '' */
.listing-icon-download-cloud:before { content: '\f0ed'; } /* '' */
.listing-icon-upload-cloud:before { content: '\f0ee'; } /* '' */
.listing-icon-plus-squared:before { content: '\f0fe'; } /* '' */
.listing-icon-angle-double-left:before { content: '\f100'; } /* '' */
.listing-icon-angle-double-right:before { content: '\f101'; } /* '' */
.listing-icon-angle-double-up:before { content: '\f102'; } /* '' */
.listing-icon-angle-double-down:before { content: '\f103'; } /* '' */
.listing-icon-angle-left:before { content: '\f104'; } /* '' */
.listing-icon-angle-right:before { content: '\f105'; } /* '' */
.listing-icon-angle-up:before { content: '\f106'; } /* '' */
.listing-icon-angle-down:before { content: '\f107'; } /* '' */
.listing-icon-share:before { content: '\f109'; } /* '' */
.listing-icon-trash:before { content: '\f10b'; } /* '' */
.listing-icon-v-ellipsis-3:before { content: '\f10c'; } /* '' */
.listing-icon-v-ellipsis-1:before { content: '\f10d'; } /* '' */
.listing-icon-ellispsis:before { content: '\f10e'; } /* '' */
.listing-icon-v-ellipsis-2:before { content: '\f10f'; } /* '' */
.listing-icon-spinner:before { content: '\f110'; } /* '' */
.listing-icon-v-ellipsis:before { content: '\f111'; } /* '' */
.listing-icon-checked:before { content: '\f112'; } /* '' */
.listing-icon-checked-2:before { content: '\f113'; } /* '' */
.listing-icon-checked-1:before { content: '\f114'; } /* '' */
.listing-icon-close:before { content: '\f115'; } /* '' */
.listing-icon-close-2:before { content: '\f116'; } /* '' */
.listing-icon-close-3:before { content: '\f117'; } /* '' */
.listing-icon-close-1:before { content: '\f118'; } /* '' */
.listing-icon-info:before { content: '\f129'; } /* '' */
.listing-icon-angle-circled-left:before { content: '\f137'; } /* '' */
.listing-icon-angle-circled-right:before { content: '\f138'; } /* '' */
.listing-icon-angle-circled-up:before { content: '\f139'; } /* '' */
.listing-icon-angle-circled-down:before { content: '\f13a'; } /* '' */
.listing-icon-bullseye:before { content: '\f140'; } /* '' */
.listing-icon-ellipsis-1:before { content: '\f141'; } /* '' */
.listing-icon-ellipsis-vert:before { content: '\f142'; } /* '' */
.listing-icon-minus-squared:before { content: '\f146'; } /* '' */
.listing-icon-minus-squared-alt:before { content: '\f147'; } /* '' */
.listing-icon-ok-squared:before { content: '\f14a'; } /* '' */
.listing-icon-sort-name-up:before { content: '\f15d'; } /* '' */
.listing-icon-sort-name-down:before { content: '\f15e'; } /* '' */
.listing-icon-sort-alt-up:before { content: '\f160'; } /* '' */
.listing-icon-sort-alt-down:before { content: '\f161'; } /* '' */
.listing-icon-sort-number-up:before { content: '\f162'; } /* '' */
.listing-icon-sort-number-down:before { content: '\f163'; } /* '' */
.listing-icon-down:before { content: '\f175'; } /* '' */
.listing-icon-up:before { content: '\f176'; } /* '' */
.listing-icon-left:before { content: '\f177'; } /* '' */
.listing-icon-right:before { content: '\f178'; } /* '' */
.listing-icon-apple:before { content: '\f179'; } /* '' */
.listing-icon-windows:before { content: '\f17a'; } /* '' */
.listing-icon-linux:before { content: '\f17c'; } /* '' */
.listing-icon-wheelchair:before { content: '\f193'; } /* '' */
.listing-icon-plus-squared-alt:before { content: '\f196'; } /* '' */
.listing-icon-google:before { content: '\f1a0'; } /* '' */
.listing-icon-file-pdf:before { content: '\f1c1'; } /* '' */
.listing-icon-file-word:before { content: '\f1c2'; } /* '' */
.listing-icon-file-excel:before { content: '\f1c3'; } /* '' */
.listing-icon-file-code:before { content: '\f1c9'; } /* '' */
.listing-icon-git:before { content: '\f1d3'; } /* '' */
.listing-icon-sliders:before { content: '\f1de'; } /* '' */
.listing-icon-share-2:before { content: '\f1e0'; } /* '' */
.listing-icon-paypal:before { content: '\f1ed'; } /* '' */
.listing-icon-cc-visa:before { content: '\f1f0'; } /* '' */
.listing-icon-cc-mastercard:before { content: '\f1f1'; } /* '' */
.listing-icon-cc-discover:before { content: '\f1f2'; } /* '' */
.listing-icon-cc-amex:before { content: '\f1f3'; } /* '' */
.listing-icon-cc-paypal:before { content: '\f1f4'; } /* '' */
.listing-icon-cc-stripe:before { content: '\f1f5'; } /* '' */
.listing-icon-trash-4:before { content: '\f1f8'; } /* '' */
.listing-icon-toggle-off:before { content: '\f204'; } /* '' */
.listing-icon-toggle-on:before { content: '\f205'; } /* '' */
.listing-icon-venus:before { content: '\f221'; } /* '' */
.listing-icon-mars:before { content: '\f222'; } /* '' */
.listing-icon-transgender:before { content: '\f224'; } /* '' */


/*
   Animation example, for spinners
*/
.animate-spin {
  -moz-animation: spin 2s infinite linear;
  -o-animation: spin 2s infinite linear;
  -webkit-animation: spin 2s infinite linear;
  animation: spin 2s infinite linear;
  display: inline-block;
}
@-moz-keyframes spin {
  0% {
    -moz-transform: rotate(0deg);
    -o-transform: rotate(0deg);
    -webkit-transform: rotate(0deg);
    transform: rotate(0deg);
  }

  100% {
    -moz-transform: rotate(359deg);
    -o-transform: rotate(359deg);
    -webkit-transform: rotate(359deg);
    transform: rotate(359deg);
  }
}
@-webkit-keyframes spin {
  0% {
    -moz-transform: rotate(0deg);
    -o-transform: rotate(0deg);
    -webkit-transform: rotate(0deg);
    transform: rotate(0deg);
  }

  100% {
    -moz-transform: rotate(359deg);
    -o-transform: rotate(359deg);
    -webkit-transform: rotate(359deg);
    transform: rotate(359deg);
  }
}
@-o-keyframes spin {
  0% {
    -moz-transform: rotate(0deg);
    -o-transform: rotate(0deg);
    -webkit-transform: rotate(0deg);
    transform: rotate(0deg);
  }

  100% {
    -moz-transform: rotate(359deg);
    -o-transform: rotate(359deg);
    -webkit-transform: rotate(359deg);
    transform: rotate(359deg);
  }
}
@-ms-keyframes spin {
  0% {
    -moz-transform: rotate(0deg);
    -o-transform: rotate(0deg);
    -webkit-transform: rotate(0deg);
    transform: rotate(0deg);
  }

  100% {
    -moz-transform: rotate(359deg);
    -o-transform: rotate(359deg);
    -webkit-transform: rotate(359deg);
    transform: rotate(359deg);
  }
}
@keyframes spin {
  0% {
    -moz-transform: rotate(0deg);
    -o-transform: rotate(0deg);
    -webkit-transform: rotate(0deg);
    transform: rotate(0deg);
  }

  100% {
    -moz-transform: rotate(359deg);
    -o-transform: rotate(359deg);
    -webkit-transform: rotate(359deg);
    transform: rotate(359deg);
  }
}

div.django-listing-container table.django-listing th {
    vertical-align: text-bottom;
}

div.django-listing-container table.django-listing th.sortable a {
    padding-right: 20px;
    display: block;
    position: relative;
    text-decoration: none;
}

div.django-listing-container table.django-listing th.sortable span.sorting {
    position: absolute;
    top: 0px;
    right: 0px;
    bottom: 0px;
    width: 20px;
}

div.django-listing-container table.django-listing {
    margin: 0 0 6px 0;
    width: 100%;
}

div.django-listing-container table.django-listing.table-bordered {
    box-shadow: 0 1px 3px rgba(0, 0, 0, 0.2);
    display: table;
}

div.django-listing-container div.django-listing div.div-row {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -ms-flex-wrap: wrap;
    flex-wrap: wrap;
}

div.django-listing-container div.django-listing.div-striped div.row-container:nth-of-type(odd) {
    background: #e9e9e9;
}

div.django-listing-container div.django-listing.div-hover div.row-container:hover {
    background: #ccc;
}

div.django-listing-container div.django-listing.div-bordered {
    border: 1px solid #cccccc;
}

div.django-listing-container ul.pagination {
    justify-content: center;
    align-items: center;
}

div.django-listing-container ul.pagination-groups {
    margin-top: 20px;
    display: flex;
    justify-content: center;
    align-items: center;
    padding-left: 0;
}

div.django-listing-container ul.pagination-groups > li {
    list-style: none;
    margin: 0;
    padding: 0;
}

div.django-listing-container div.variationstoolbaritem ul {
    display: flex;
    justify-content: center;
    align-items: center;
    margin: 0;
    padding: 0;
}

div.django-listing-container div.variationstoolbaritem li {
    list-style: none;
}

div.django-listing-container nav.toolbar label {
    margin: 0;
}

div.django-listing-container ul.pagination li.scale_pages ul {
    padding: 0 10px;
    list-style: none;
    display: flex;
}

div.django-listing-container ul li.pagination-info {
    padding: 0 10px;
}

div.django-listing-container ul li.row-info {
    padding: 0 10px;
}

div.django-listing-container ul li.goto-page {
    padding: 0 10px;
}

div.django-listing-container .btn-toolbar select {
    font-family: django_listing, arial;
    height: 24px;
    vertical-align: middle;
}

div.django-listing-container .btn-toolbar .sortdropdowntoolbaritem a {
    font-family: django_listing, arial;
}

div.django-listing-container form.goto-page {
    display:inline;
}

div.django-listing-container form.goto-page input {
    width: 40px;
}


div.django-listing-container td.cls-totalcolumn {
    font-weight: bold;
}

@media (min-width: 768px) {
    div.django-listing-container td.type-str.cls-filesizecolumn,
    div.django-listing-container td.type-int,
    div.django-listing-container td.type-float,
    div.django-listing-container td.agg-minmax,
    div.django-listing-container td.agg-minmaxavg {
        text-align: right;
    }
}

div.django-listing-container td.type-bool  {
    vertical-align: middle;
}

div.django-listing-container td.type-bool input {
    margin: auto;
    width: inherit;
}

td.render-error {
    background-color: red;
    color: white;
    font-weight: bold;
}

form.listing-form {
    margin: 10px 0 20px;
}

form.listing-form div.form-row {
    flex-wrap: nowrap;
}

form.listing-form div.form-field {
    width: 100%;
    margin: 5px;
}

div.django-listing-container div.form-field.errors,
div.django-listing-container ul.listing-row-form-errors,
form.listing-form div.form-field.errors {
    background-color: rgba(255,0,0,.25);
    padding:10px;
    border: 1px solid red;
    border-radius: 6px;
    color: red;
    font-weight: bold;
}

div.django-listing-container ul.listing-row-form-errors li {
    list-style: none;
}

div.django-listing-container div.form-field.errors ul.errorlist,
form.listing-form div.form-field.errors ul.errorlist {
    list-style: none;
    padding: 0;
    display: inline;
}


form.listing-form div.form-field.errors ul.errorlist li {
    display: inline;
}

div.django-listing-container div.form-field.errors input,
form.listing-form div.form-field.errors input {
    border-color: red;
}

form span.asteriskField {
  color: #FF0000;
  padding-left: 5px; }

div.django-listing-container .bottom-toolbar {
    margin-top: 10px;
}

div.django-listing-container div.form-field.errors input:focus,
form.listing-form div.form-field.errors input:focus {
    box-shadow: 0 0 0 0.2rem rgba(255, 0, 0, 0.25);
}

form.listing-form div.form-field label {
    margin-bottom: .1em;
}

form.listing-form div.form-field.inline div.label_input {
    display: flex;
}

form.listing-form div.form-field.inline label {
    white-space: nowrap;
    margin: auto 5px auto 0;
}

form.listing-form div.form-field span.ending {
    white-space: nowrap;
    margin: auto 4px;
}

form.listing-form div.form-field p.help {
    font-size: 9px;
    color: #888888;
}

div.django-listing-container div.form-field ul.multiple-checkboxes,
form.listing-form div.form-field ul.multiple-checkboxes {
    list-style: none;
    padding-left: 10px;
}

div.django-listing-container div.form-field ul.multiple-checkboxes input,
form.listing-form div.form-field ul.multiple-checkboxes input {
    vertical-align: middle;
}

div.django-listing-container div.form-field ul.multiple-checkboxes.inline,
form.listing-form div.form-field ul.multiple-checkboxes.inline {
    display: flex;
}

div.django-listing-container div.form-field ul.multiple-checkboxes.inline li,
form.listing-form div.form-field ul.multiple-checkboxes.inline li {
    margin-right: 10px;
}

div.django-listing-container div.form-field ul.multiple-radios,
form.listing-form div.form-field ul.multiple-radios {
    list-style: none;
    padding-left: 10px;
}

div.django-listing-container div.form-field ul.multiple-radios li,
form.listing-form div.form-field ul.multiple-radios li {
    white-space: nowrap;
}

div.django-listing-container div.form-field ul.multiple-radios input,
form.listing-form div.form-field ul.multiple-radios input {
    vertical-align: middle;
}

div.django-listing-container div.form-field ul.multiple-radios.inline,
form.listing-form div.form-field ul.multiple-radios.inline {
    display: flex;
}

div.django-listing-container div.form-field ul.multiple-radios.inline li,
form.listing-form div.form-field ul.multiple-radios.inline li {
    margin-right: 10px;
}

div.django-listing-container div.form-buttons,
form.listing-form div.form-buttons {
    text-align: center;
    margin-top: 20px;
}

div.django-listing-selecting.selection_position_hidden tr.selected {
    background-color: #333333;
    color: #ffffff;
    cursor: pointer;
}

div.django-listing-selecting.selection_position_hidden tr {
    cursor: pointer;
}

div.django-listing-container thead th.col-selection_checkbox  {
    vertical-align: middle;
}

div.django-listing-container div.row-container {
    position: relative;
}

div.django-listing-container div.row-container div.selection-overlay {
    position: absolute;
    z-index: 999;
    height: 100%;
    width: 100%;
    cursor: pointer;
}

div.django-listing-container div.row-container div.selection-overlay div.checkbox {
    margin: 2px;
}

div.django-listing-container div.row-container div.selection-overlay div.checkbox span.unselected-icon {
    display: block;
    opacity: 0.5;
}

div.django-listing-container div.row-container div.selection-overlay div.checkbox span.selected-icon {
    display: none;
}

div.django-listing-container div.row-container.selected div.selection-overlay div.checkbox span.unselected-icon {
    display: none;
}

div.django-listing-container div.row-container.selected div.selection-overlay div.checkbox span.selected-icon {
    display: block;
}

div.django-listing-container div.row-container div.selection-overlay div.checkbox {
    margin: 0px;
    font-size: 28px;
    opacity: 1;
    cursor: pointer;
    color: white;
    text-shadow:
       3px 3px 10px rgba(0, 0, 0, 0.5),
     -1px -1px 1px #444444,
      1px -1px 1px #444444,
      -1px 1px 1px #444444,
       1px 1px 1px #444444;
}


div.django-listing-container div.row-container div.selection-overlay.hover {
    position: absolute;
    z-index: 999;
    height: initial;
    width: initial;
}

div.django-listing-container div.row-container div.selection-overlay.hover div.checkbox {
    margin: 2px;
}

div.django-listing-container div.row-container div.selection-overlay.hover div.checkbox span.unselected-icon {
    display: none;
}

div.django-listing-container div.row-container:hover div.selection-overlay.hover div.checkbox span.unselected-icon {
    display: block;
    opacity: 0.5;
    cursor: pointer;
}

div.django-listing-container div.row-container:hover div.selection-overlay.hover div.checkbox span.unselected-icon:hover {
    opacity: 1;
    cursor: pointer;
}

div.django-listing-container div.row-container div.selection-overlay.hover div.checkbox span.selected-icon {
    display: none;
}

div.django-listing-container div.row-container.selected div.selection-overlay.hover div.checkbox span.unselected-icon {
    display: none;
}

div.django-listing-container div.row-container.selected div.selection-overlay.hover div.checkbox span.selected-icon {
    display: block;
    cursor: pointer;
}

div.thumbnail.row-container {
    padding: 0;
}

div.thumbnail-container {
    padding-left: 10px;
}

div.listing-selection-menu .menu-icon {
    font-weight: normal;
    font-size: 16px;
    vertical-align: middle;
}

div.listing-selection-menu button {
    margin: 0 5px;
}

div.listing-selection-menu a {
    cursor: pointer;
}

.listing-selection-menu {
    display: none;
    background-color: #666666;
    color: #ffffff;
    font-size: 20px;
    padding: 4px 20px;
}

.listing-selection-menu button.submit-icon {
    border: none;
    background: none;
    color: inherit;
    cursor: pointer;
}

.listing-selection-menu button.submit-icon:focus {
    outline: none;
}

ul.errorlist.nonfield {
    background-color: #fbb;
    color: red;
    padding: 10px;
    border: 1px solid red;
    border-radius: 4px;
}

ul.errorlist.nonfield li {
    list-style: none;
}

ul.actions-buttons {
    margin: 0;
    padding: 0;
}

ul.actions-buttons li {
    list-style: none;
    display: inline;
    margin: 1px 2px;
}

ul.actions-buttons li button, ul.actions-buttons li a {
    padding: 0 1px 1px 0;
    font-size: 12px;
}

ul.actions-buttons li button.disabled, ul.actions-buttons li a.disabled {
    background-color: #aaa;
    border-color: #aaa;
}

ul.actions-buttons li button span.text,ul.actions-buttons li a span.text {
    padding: 0 2px;
}

.django-listing-container {
    position: relative;
}

.django-listing-container div.listing-spinner {
    display: none;
    position: absolute;
    top: 50%;
    left: 50%;
    transform: translate(-50%, -50%);
    -ms-transform: translate(-50%, -50%);
    text-align: center;
}

.django-listing-container.spinning .django-listing {
    opacity: 0.3;
}

.django-listing-container.spinning div.listing-spinner {
    display: block;
    opacity: 1;
    z-index: 1000;
}

div.listing-spinner {
    font-size: 32px;
}

table.object-popup td {
    padding-right: 10px;
}

table.object-popup td.section {
    padding-top: 10px;
}

table.object-popup td.section span {
    font-weight: bold;
    font-size: 125%;
    text-decoration: underline;
}

table.object-popup th {
    vertical-align: top;
}

.empty-listing-upload-button {
    text-align: center;
}

.empty-listing-upload-drop-here {
    text-align: center;
    margin: 16px;
    color: #8d8d8d;
}

empty-listing-upload-accepted-files {
    text-align: center;
    margin: 16px;
    font-style: italic;
}

form.dropzone .dz-preview.dz-image-preview {
    background: none;
}

form.dropzone {
    min-height: 150px;
    border: none;
    background: none;
    padding: initial;
    position: relative;
}

form.dropzone .dz-preview .dz-image {
    border-radius: 8px;
}

form.dropzone .drag-overlay {
    background: #8888FFA0;
    border: 3px dashed #4444FF;
    width: 100%;
    height: 100%;
    position: absolute;
    top: 0;
    left: 0;
    display: none;
    z-index: 10;
    border-radius: 1rem;
}

form.dropzone.drag-over .drag-overlay {
    display: flex;
}

form.dropzone .drag-overlay .overlay-inner {
    margin: auto;
    font-size: 6rem;
    color: #FFFFFF;
}

form.dropzone.dz-drag-hover {
    border: none;
}

.dz-success-mark svg path {
    fill: #28a745;
    fill-opacity: 1;
    stroke: #444444;
    stroke-opacity: 1;
}

.dz-error-mark svg g g {
    fill: red;
    fill-opacity: 1;
    stroke: #444444;
    stroke-opacity: 1;
}