// Bootstrap variables
$font-family-sans-serif: Roboto, system-ui, -apple-system, "Segoe UI", "Helvetica Neue", "Noto Sans", "Liberation Sans", Arial, sans-serif, "Apple Color Emoji", "Segoe UI Emoji", "Segoe UI Symbol", "Noto Color Emoji";
$font-size-base: 0.85rem;

@import "bootstrap/mixins";
@import "bootstrap/functions";
@import "bootstrap/variables";

@import "fonts";
@import "main";